from setuptools import setup, find_packages

setup(
    name="egglord",
    version="1.0.1",
    packages=find_packages(),
    description="A simple Python library that motivates you every 10-120 seconds.",
    author="egglord",
    python_requires=">=3.7",
)
